==> nextcloud-20.0.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/ru.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Указанный оператор неверен",
    "The given regular expression is invalid" : "Указанное регулярное выражение неверно",
    "The given file size is invalid" : "Укзанный размер файла неверен",
    "The given tag id is invalid" : "Указанная метка неверна",
    "The given IP range is invalid" : "Указанный диапазон IP адресов неверен",
    "The given IP range is not valid for IPv4" : "Указанный диапазон IP не соответствует IPv4",
    "The given IP range is not valid for IPv6" : "Указанный диапазон IP не соответствует IPv6",
    "The given time span is invalid" : "Указанный интервал времени неверен",
    "The given start time is invalid" : "Указаное время начала неверно",
    "The given end time is invalid" : "Указаное время окончания неверно",
    "The given group does not exist" : "Указанная группа не существует",
    "File" : "Файл",
    "File created" : "Файл создан",
    "File updated" : "Файл обновлен",
    "File renamed" : "Файл переименован",
    "File deleted" : "Файл удален",
    "File accessed" : "Файл доступен",
    "File copied" : "Файл скопирован",
    "Tag assigned" : "Метка присвоена",
    "Someone" : "Пользователь",
    "%s created %s" : "%s создал(а) %s",
    "%s modified %s" : "%s изменил(а) %s",
    "%s deleted %s" : "%s удалил(а) %s",
    "%s accessed %s" : "%s получил(а) доступ к %s",
    "%s renamed %s" : "%s переименовал(а) %s",
    "%s copied %s" : "%s скопировал(а) %s",
    "%s assigned %s to %s" : "%s присвоила(а) метку %s файлу %s",
    "Operation #%s does not exist" : "Операция #%s не существует",
    "Entity %s does not exist" : "Сущность %s не существует",
    "Entity %s is invalid" : "Сущность %s неверна",
    "No events are chosen." : "События не выбраны.",
    "Entity %s has no event %s" : "У сущности %s нет события %s",
    "Operation %s does not exist" : "Операция %s не существует",
    "Operation %s is invalid" : "Операция %s неверна",
    "At least one check needs to be provided" : "Необходимо задать как минимум одну проверку",
    "Invalid check provided" : "Задана неверная проверка",
    "Check %s does not exist" : "Проверка %s не существует",
    "Check %s is invalid" : "Проверка %s неверна",
    "Check %s is not allowed with this entity" : "Проверка %s не разрешена с этой сущностью",
    "Check #%s does not exist" : "Проверка #%s не существует",
    "Check %s is invalid or does not exist" : "Проверка %s неверна или не существует",
    "Flow" : "Обработка файлов",
    "Nextcloud workflow engine" : "Механизм обработки Nextcloud",
    "Select a filter" : "Выберите фильтр",
    "Select a comparator" : "Выберите компаратор",
    "Select a file type" : "Выберите тип файла",
    "e.g. httpd/unix-directory" : "например, каталог httpd/unix",
    "Folder" : "Каталог",
    "Images" : "Изображения",
    "Office documents" : "Офисные документы",
    "PDF documents" : "PDF документы",
    "Custom mimetype" : "Пользовательский тип mime",
    "Select a tag" : "Выберите метку",
    "No results" : "Нет результатов",
    "%s (invisible)" : "%s (невидимый)",
    "%s (restricted)" : "%s (ограниченный)",
    "Please enter a valid time span" : "Введите верный диапазон",
    "Select a request URL" : "Выберите URL запроса",
    "Predefined URLs" : "Предопределенные URL",
    "Files WebDAV" : "Файлы WebDAV",
    "Others" : "Другие",
    "Custom URL" : "Пользовательский URL",
    "Select a user agent" : "Выберите user agent",
    "Android client" : "клиент для Android",
    "iOS client" : "клиент для iOS",
    "Desktop client" : "клиент для ПК",
    "Thunderbird & Outlook addons" : "Дополнения для Thunderbird и Outlook",
    "Custom user agent" : "Пользовательский user agent",
    "At least one event must be selected" : "Необходимо выбрать как минимум одно событие",
    "Add new flow" : "Добавить обработку",
    "When" : "Когда",
    "and" : "и",
    "Cancel" : "Отменить",
    "Delete" : "Удалить",
    "The configuration is invalid" : "Конфигурация неверна",
    "Active" : "Активный",
    "Save" : "Сохранить",
    "Available flows" : "Доступные обработки",
    "For details on how to write your own flow, check out the development documentation." : "За дополнительными сведениями о написании собственных обработок, обратитесь к документации.",
    "More flows" : "Дополнительные обработки",
    "Browse the app store" : "Перейти в магазин приложений",
    "Show less" : "Показывать меньше",
    "Show more" : "Показывать больше",
    "Configured flows" : "Настроенные обработки",
    "Your flows" : "Ваши обработки",
    "matches" : "соответствует",
    "does not match" : "не соответствует",
    "is" : "равняется",
    "is not" : "не равняется",
    "File name" : "Имя файла",
    "File MIME type" : "MIME-тип файла",
    "File size (upload)" : "Размер передаваемого на сервер файла",
    "less" : "меньше",
    "less or equals" : "меньше либо равно",
    "greater or equals" : "больше либо равно",
    "greater" : "больше",
    "Request remote address" : "Адрес, с которого производится запрос",
    "matches IPv4" : "соответствует IPv4",
    "does not match IPv4" : "не соответствует IPv4",
    "matches IPv6" : "соответствует IPv6",
    "does not match IPv6" : "не соответствует IPv6",
    "File system tag" : "Метка файла",
    "is tagged with" : "файл помечен",
    "is not tagged with" : "файл не помечен",
    "Request URL" : "URL запроса",
    "Request time" : "Время запроса",
    "between" : "между",
    "not between" : "не между",
    "Request user agent" : "Используемое приложение (user agent)",
    "User group membership" : "Участие в группе пользователей",
    "is member of" : "является участником",
    "is not member of" : "не является участником"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-26.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/ru.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Указанный оператор неверен",
    "The given regular expression is invalid" : "Указанное регулярное выражение неверно",
    "The given file size is invalid" : "Укзанный размер файла неверен",
    "The given tag id is invalid" : "Указанная метка неверна",
    "The given IP range is invalid" : "Указанный диапазон IP адресов неверен",
    "The given IP range is not valid for IPv4" : "Указанный диапазон IP не соответствует IPv4",
    "The given IP range is not valid for IPv6" : "Указанный диапазон IP не соответствует IPv6",
    "The given time span is invalid" : "Указанный интервал времени неверен",
    "The given start time is invalid" : "Указаное время начала неверно",
    "The given end time is invalid" : "Указаное время окончания неверно",
    "The given group does not exist" : "Указанная группа не существует",
    "File" : "Файл",
    "File created" : "Файл создан",
    "File updated" : "Файл обновлен",
    "File renamed" : "Файл переименован",
    "File deleted" : "Файл удален",
    "File accessed" : "Файл доступен",
    "File copied" : "Файл скопирован",
    "Tag assigned" : "Метка присвоена",
    "Someone" : "Пользователь",
    "%s created %s" : "%s создал(а) %s",
    "%s modified %s" : "%s изменил(а) %s",
    "%s deleted %s" : "%s удалил(а) %s",
    "%s accessed %s" : "%s получил(а) доступ к %s",
    "%s renamed %s" : "%s переименовал(а) %s",
    "%s copied %s" : "%s скопировал(а) %s",
    "%s assigned %s to %s" : "%s присвоила(а) метку %s файлу %s",
    "Operation #%s does not exist" : "Операция #%s не существует",
    "Entity %s does not exist" : "Сущность %s не существует",
    "Entity %s is invalid" : "Сущность %s неверна",
    "No events are chosen." : "События не выбраны.",
    "Entity %s has no event %s" : "У сущности %s нет события %s",
    "Operation %s does not exist" : "Операция %s не существует",
    "Operation %s is invalid" : "Операция %s неверна",
    "At least one check needs to be provided" : "Необходимо задать как минимум одну проверку",
    "The provided operation data is too long" : "Заданы слишком длинные данные для операции",
    "Invalid check provided" : "Задана неверная проверка",
    "Check %s does not exist" : "Проверка %s не существует",
    "Check %s is invalid" : "Проверка %s неверна",
    "Check %s is not allowed with this entity" : "Проверка %s не разрешена с этой сущностью",
    "The provided check value is too long" : "Задано слишком длинное проверочное значение",
    "Check #%s does not exist" : "Проверка #%s не существует",
    "Check %s is invalid or does not exist" : "Проверка %s неверна или не существует",
    "Flow" : "Обработка файлов",
    "Nextcloud workflow engine" : "Механизм обработки Nextcloud",
    "Select a filter" : "Выберите фильтр",
    "Select a comparator" : "Выберите компаратор",
    "Select a file type" : "Выберите тип файла",
    "e.g. httpd/unix-directory" : "например, каталог httpd/unix",
    "Folder" : "Каталог",
    "Images" : "Изображения",
    "Office documents" : "Офисные документы",
    "PDF documents" : "PDF документы",
    "Custom MIME type" : "Пользовательский тип MIME",
    "Custom mimetype" : "Пользовательский тип mime",
    "Please enter a valid time span" : "Введите верный диапазон",
    "Select a request URL" : "Выберите URL запроса",
    "Files WebDAV" : "Файлы WebDAV",
    "Custom URL" : "Пользовательский URL",
    "Select a user agent" : "Выберите user agent",
    "Android client" : "клиент для Android",
    "iOS client" : "клиент для iOS",
    "Desktop client" : "клиент для ПК",
    "Thunderbird & Outlook addons" : "Дополнения для Thunderbird и Outlook",
    "Custom user agent" : "Пользовательский user agent",
    "At least one event must be selected" : "Необходимо выбрать как минимум одно событие",
    "Add new flow" : "Добавить обработку",
    "When" : "Когда",
    "and" : "и",
    "Cancel" : "Отменить",
    "Delete" : "Удалить",
    "The configuration is invalid" : "Конфигурация неверна",
    "Active" : "Активный",
    "Save" : "Сохранить",
    "Available flows" : "Доступные обработки",
    "For details on how to write your own flow, check out the development documentation." : "За дополнительными сведениями о написании собственных обработок, обратитесь к документации.",
    "More flows" : "Дополнительные обработки",
    "Browse the App Store" : "Просмотреть магазин приложений",
    "Show less" : "Показывать меньше",
    "Show more" : "Показывать больше",
    "Configured flows" : "Настроенные обработки",
    "Your flows" : "Ваши обработки",
    "matches" : "соответствует",
    "does not match" : "не соответствует",
    "is" : "равняется",
    "is not" : "не равняется",
    "File name" : "Имя файла",
    "File MIME type" : "MIME-тип файла",
    "File size (upload)" : "Размер передаваемого на сервер файла",
    "less" : "меньше",
    "less or equals" : "меньше либо равно",
    "greater or equals" : "больше либо равно",
    "greater" : "больше",
    "Request remote address" : "Адрес, с которого производится запрос",
    "matches IPv4" : "соответствует IPv4",
    "does not match IPv4" : "не соответствует IPv4",
    "matches IPv6" : "соответствует IPv6",
    "does not match IPv6" : "не соответствует IPv6",
    "File system tag" : "Метка файла",
    "is tagged with" : "файл помечен",
    "is not tagged with" : "файл не помечен",
    "Request URL" : "URL запроса",
    "Request time" : "Время запроса",
    "between" : "между",
    "not between" : "не между",
    "Request user agent" : "Используемое приложение (user agent)",
    "User group membership" : "Участие в группе пользователей",
    "is member of" : "является участником",
    "is not member of" : "не является участником",
    "Select a tag" : "Выберите метку",
    "No results" : "Нет результатов",
    "%s (invisible)" : "%s (невидимый)",
    "%s (restricted)" : "%s (ограниченный)",
    "Predefined URLs" : "Предопределенные URL",
    "Others" : "Другие"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
